@@ -4,6 +4,9 @@
 //! [ANSI escape code (Wikipedia)](https://en.wikipedia.org/wiki/ANSI_escape_code).
 use std::collections::VecDeque;
 
+#[cfg(nu_ansi_term)]
+use nu_ansi_term;
+
 #[cfg(ansi_term)]
 use ansi_term;
 
@@ -63,6 +66,34 @@ impl Color {
         }
     }
 
+    /// Convert to a `nu_ansi_term::Color` (if the `nu_ansi_term` feature is enabled).
+    #[cfg(feature = "nu-ansi-term")]
+    pub fn to_nu_ansi_term_color(&self) -> nu_ansi_term::Color {
+        match self {
+            Color::RGB(r, g, b) => nu_ansi_term::Color::Rgb(*r, *g, *b),
+            Color::Fixed(n) => nu_ansi_term::Color::Fixed(*n),
+            Color::Black => nu_ansi_term::Color::Black,
+            Color::Red => nu_ansi_term::Color::Red,
+            Color::Green => nu_ansi_term::Color::Green,
+            Color::Yellow => nu_ansi_term::Color::Yellow,
+            Color::Blue => nu_ansi_term::Color::Blue,
+            Color::Magenta => nu_ansi_term::Color::Purple,
+            Color::Cyan => nu_ansi_term::Color::Cyan,
+            Color::White => nu_ansi_term::Color::White,
+
+            // Below items are a rough translations to 256 colors as
+            // we do not have bright varients available on ansi-term
+            Color::BrightBlack => nu_ansi_term::Color::Fixed(8),
+            Color::BrightRed => nu_ansi_term::Color::Fixed(9),
+            Color::BrightGreen => nu_ansi_term::Color::Fixed(10),
+            Color::BrightYellow => nu_ansi_term::Color::Fixed(11),
+            Color::BrightBlue => nu_ansi_term::Color::Fixed(12),
+            Color::BrightMagenta => nu_ansi_term::Color::Fixed(13),
+            Color::BrightCyan => nu_ansi_term::Color::Fixed(14),
+            Color::BrightWhite => nu_ansi_term::Color::Fixed(15),
+        }
+    }
+
     /// Convert to a `crossterm::style::Color` (if the `crossterm` feature is enabled).
     #[cfg(feature = "crossterm")]
     pub fn to_crossterm_color(&self) -> crossterm::style::Color {
@@ -376,6 +407,23 @@ impl Style {
         }
     }
 
+    /// Convert to a `nu_ansi_term::Style` (if the `nu_ansi_term` feature is enabled).
+    #[cfg(feature = "nu-ansi-term")]
+    pub fn to_nu_ansi_term_style(&self) -> nu_ansi_term::Style {
+        nu_ansi_term::Style {
+            foreground: self.foreground.as_ref().map(Color::to_nu_ansi_term_color),
+            background: self.background.as_ref().map(Color::to_nu_ansi_term_color),
+            is_bold: self.font_style.bold,
+            is_dimmed: self.font_style.dimmed,
+            is_italic: self.font_style.italic,
+            is_underline: self.font_style.underline,
+            is_blink: self.font_style.rapid_blink || self.font_style.slow_blink,
+            is_reverse: self.font_style.reverse,
+            is_hidden: self.font_style.hidden,
+            is_strikethrough: self.font_style.strikethrough,
+        }
+    }
+
     /// Convert to a `crossterm::style::ContentStyle` (if the `crossterm` feature is enabled).
     #[cfg(feature = "crossterm")]
     pub fn to_crossterm_style(&self) -> crossterm::style::ContentStyle {
